@@ -707,9 +707,6 @@ void mclear_lastline()
 
 void xclear()
 {
-//#ifndef __CYGWIN__
-//#define __CYGWIN__
-//#endif
 #if defined(__CYGWIN__)
     int y;
     for(y=0; y<mgetmaxy()-1; y++) {
@@ -717,13 +714,17 @@ void xclear()
     }
     mclear_lastline();
 #else
-    int y;
-    for(y=0; y<mgetmaxy()-1; y++) {
-        mclear_online(y);
+    if(getenv("MFILER4_CLEAR_WAY")) {
+        int y;
+        for(y=0; y<mgetmaxy()-1; y++) {
+            mclear_online(y);
+        }
+        mclear_lastline();
+        //erase();
+    }
+    else {
+        clear();
     }
-    mclear_lastline();
-    //erase();
-    //clear();
 #endif
 }
 
