@@ -752,7 +752,7 @@ int main(int argc, char* argv[])
     CHECKML_BEGIN();    // start to watch memory leak
 
     /// initialization for envronment variable ///
-    setenv("VERSION", "1.2.2", 1);
+    setenv("VERSION", "1.2.3", 1);
     setenv("MFILER4_DOCDIR", DOCDIR, 1);
     setenv("MFILER4_DATAROOTDIR", DOCDIR, 1);
 
@@ -824,6 +824,10 @@ int main(int argc, char* argv[])
                     }
                     break;
 
+                case 'x':
+                    setenv("MFILER4_CLEAR_WAY", "1", 1);
+                    break;
+
                 default:
                     usage();
             }
